@@ -3,6 +3,8 @@ from logging.config import dictConfig
 from enum import Enum
 from contextlib import contextmanager
 
+from pybrary.func import caller
+
 from .config import config
 
 dictConfig(config)
@@ -30,11 +32,14 @@ class Logger:
             self.verbosity = back
 
     def debug(self, *a):
-        _logger_.debug(*a)
+        if len(a)>1:
+            _logger_.debug(*a)
+        else:
+            _logger_.debug(f'{caller()} -> {a[0]}')
 
     def info(self, *a):
         if self.verbosity.value < Verbosity.normal.value:
-            _logger_.debug(*a)
+            self.debug(*a)
         else:
             _logger_.info(*a)
 
